@@ -14,7 +14,7 @@ from ..provider import async_arxiv as arxiv
 
 
 class PaperParams(BaseModel):
-    pdf_path: str
+    pdf: str
     query: str
     key_word: str
     filter_keys: Optional[list[str]] = None
@@ -24,7 +24,7 @@ class PaperParams(BaseModel):
     file_format: str
     language: str
 
-    @validator("pdf_path")
+    @validator("pdf")
     def pdf_path_must_exist(cls, v):
         if not Path(v).exists():
             raise ValueError("pdf_path must exist")
@@ -80,9 +80,11 @@ class Reader(AsyncBaseReader):
         search = self.get_arxiv(max_results=max_results)
         results = list(search.results())
 
-        logger.info("all search:")
+        logger.info("All search:")
         for index, result in enumerate(results):
-            logger.info(f"{index=}, {result.title=}, {result.updated}")
+            logger.info(
+                f"{index=}, title={result.title} {result.updated.strftime('%Y-%m-%d')}"
+            )
 
         # if self.filter_keys is empty then do not filter out
         if not self.filter_keys:
@@ -104,7 +106,10 @@ class Reader(AsyncBaseReader):
         logger.info(f"filter_results: {len(filter_results)}")
         logger.info("filter_papers:")
         for index, result in enumerate(filter_results):
-            logger.info(f"{index=}, {result.title=}, {result.updated}")
+            logger.info(
+                f"{index=}, title={result.title} {result.updated.strftime('%Y-%m-%d')}"
+            )
+
         return filter_results
 
     def download_pdf(self, filter_results):
@@ -169,7 +174,7 @@ def add_subcommand(parser):
         name, help="Fetch or Summary paper from local or arxiv"
     )
     subparser.add_argument(
-        "--pdf-path",
+        "--pdf",
         type=str,
         default="",
         metavar="",
@@ -228,7 +233,7 @@ def add_subcommand(parser):
         "--file-format",
         type=str,
         default="md",
-        choices=["md", "txt", "pdf"],
+        choices=["md", "txt", "pdf", "tex"],
         metavar="",
         help="the format of the exported file, if you save the picture, it is best to be md, if not, the txt will not be messy (default: %(default)s)",
     )
@@ -253,7 +258,7 @@ def main(args):
     else:
         sort = arxiv.SortCriterion.Relevance
 
-    if args.pdf_path:
+    if args.pdf:
         reader = Reader(
             key_word=args.key_word,
             query=args.query,
@@ -262,25 +267,22 @@ def main(args):
             args=args,
         )
         reader.show_info()
-        # 开始判断是路径还是文件：
         paper_list = []
-        if args.pdf_path.endswith(".pdf"):
-            paper_list.append(Paper(path=args.pdf_path))
-            logger.info(f"read pdf file {args.pdf_path}")
+        if args.pdf.endswith(".pdf"):
+            paper_list.append(Paper(path=args.pdf))
+            logger.info(f"read pdf file {args.pdf}")
         else:
-            logger.info(f"read pdf files from path {args.pdf_path}")
-            for root, dirs, files in os.walk(args.pdf_path):
+            logger.info(f"read pdf files from path {args.pdf}")
+            for root, dirs, files in os.walk(args.pdf):
                 logger.trace(f"root: {root}, dirs: {dirs}, files: {files}")
                 for filename in files:
-                    # 如果找到PDF文件，则将其复制到目标文件夹中
                     if filename.endswith(".pdf"):
                         paper_list.append(Paper(path=os.path.join(root, filename)))
 
         logger.info("paper_num: {}".format(len(paper_list)))
-        for paper_index, paper_name in enumerate(paper_list):
-            name = paper_name.path.split("\\")[-1]
+        for paper_index, paper in enumerate(paper_list):
+            name = Path(paper.path).name
             logger.info(f"{paper_index=}, {name=}")
-
         reader.summary_with_chat(paper_list=paper_list, key_words=reader.key_word)
     else:
         reader = Reader(
